@@ -3,11 +3,15 @@ import logging
 
 # Provide shortcuts to importing Parsons submodules
 
-# If you want to be more targeted in your imports, you can set the PARSONS_SKIP_IMPORT_ALL
-# environment variable and import classes directly from the Python module where they
-# are defined.
+# If you want to be more targeted in your imports, you can set the
+# PARSONS_LIMITED_DEPENDENCIES environment variable and import classes directly
+# from the Python module where they are defined.
+# PARSONS_SKIP_IMPORT_ALL is still checked for backwards compatibility
 
-if not os.environ.get('PARSONS_SKIP_IMPORT_ALL'):
+if not (
+    os.environ.get('PARSONS_LIMITED_DEPENDENCIES')
+    or os.environ.get('PARSONS_SKIP_IMPORT_ALL')
+):
     from parsons.ngpvan.van import VAN
     from parsons.targetsmart.targetsmart_api import TargetSmartAPI
     from parsons.targetsmart.targetsmart_automation import TargetSmartAutomation
@@ -17,6 +21,10 @@ if not os.environ.get('PARSONS_SKIP_IMPORT_ALL'):
     from parsons.civis.civisclient import CivisClient
     from parsons.etl.table import Table
     from parsons.notifications.gmail import Gmail
+    from parsons.notifications.slack import Slack
+    from parsons.notifications.sendmail import SendMail
+    from parsons.notifications.smtp import SMTP
+    from parsons.google.google_admin import GoogleAdmin
     from parsons.google.google_civic import GoogleCivic
     from parsons.google.google_sheets import GoogleSheets
     from parsons.google.google_cloud_storage import GoogleCloudStorage
@@ -24,7 +32,6 @@ if not os.environ.get('PARSONS_SKIP_IMPORT_ALL'):
     from parsons.phone2action.p2a import Phone2Action
     from parsons.mobilize_america.ma import MobilizeAmerica
     from parsons.facebook_ads.facebook_ads import FacebookAds
-    from parsons.notifications.slack import Slack
     from parsons.turbovote.turbovote import TurboVote
     from parsons.sftp.sftp import SFTP
     from parsons.action_kit.action_kit import ActionKit
@@ -51,9 +58,13 @@ if not os.environ.get('PARSONS_SKIP_IMPORT_ALL'):
     from parsons.bloomerang.bloomerang import Bloomerang
     from parsons.box.box import Box
     from parsons.sisense.sisense import Sisense
+    from parsons.shopify.shopify import Shopify
     from parsons.alchemer.alchemer import SurveyGizmo, Alchemer
     from parsons.quickbase.quickbase import Quickbase
     from parsons.actblue.actblue import ActBlue
+    from parsons.redash.redash import Redash
+    from parsons.bluelink import Bluelink
+    from parsons.braintree.braintree import Braintree
 
     __all__ = [
         'VAN',
@@ -65,6 +76,7 @@ if not os.environ.get('PARSONS_SKIP_IMPORT_ALL'):
         'DBSync',
         'Table',
         'Gmail',
+        'GoogleAdmin',
         'GoogleCivic',
         'GoogleCloudStorage',
         'GoogleBigQuery',
@@ -99,10 +111,16 @@ if not os.environ.get('PARSONS_SKIP_IMPORT_ALL'):
         'Bloomerang',
         'Box',
         'Sisense',
+        'Shopify',
         'SurveyGizmo',
         'Alchemer',
         'Quickbase',
-        'ActBlue'
+        'ActBlue',
+        'Redash',
+        'Bluelink',
+        'Braintree',
+        'SMTP',
+        'SendMail'
     ]
 
 # Define the default logging config for Parsons and its submodules. For now the
