@@ -74,6 +74,8 @@ class VANConnector(object):
 
         # Paginate
         while isinstance(r, dict) and self.api.next_page_check_url(r):
+            if endpoint == 'savedLists' and not r['items']:
+                break
             r = self.api.get_request(r[self.pagination_key], **kwargs)
             data.extend(self.api.data_parse(r))
 
