@@ -4,7 +4,7 @@ import pytest
 import shutil
 import datetime
 from unittest import mock
-from parsons.etl.table import Table
+from parsons import Table
 from parsons.utilities.datetime import date_to_timestamp, parse_date
 from parsons.utilities import files
 from parsons.utilities import check_env
